@@ -10,10 +10,10 @@ function(locusIDs,batchsize=200,MaxRet=30000,showurl=FALSE,quiet=TRUE,smt=FALSE,
    locusIDs<-sort(unique(unlist(strsplit(locusIDs,",")))) 
    locusIDs<-paste(locusIDs,collapse=",")                  
    URLdef<-ncbi2r.options()
-   getURL<-paste(URLdef$front,"esearch.fcgi?db=snp&term=",locusIDs,"[LOCUS_ID]+AND&retmax=",MaxRet,"&rettype=FASTA",URLdef$back,sep="")
+   getURL<-paste(URLdef$front,"esearch.fcgi?db=snp&term=",locusIDs,"[LOCUS_ID]+AND&retmax=",formatC(MaxRet,digits=9,width=1),"&rettype=FASTA",URLdef$back,sep="")
    listofSNPs<-rep("",MaxRet)
    webget<-get.file(getURL,showurl=showurl,quiet=quiet,clean=FALSE)
-   listofSNPs<-getListFromXML(webget,sme=sme,smt=smt)
+   listofSNPs<-getListFromXML(webget,MaxRet=MaxRet,sme=sme,smt=smt)
    if(length(listofSNPs)!=0)
       listofSNPs<-paste("rs",listofSNPs,sep="")
    return(listofSNPs=listofSNPs)
